@@ -11,6 +11,7 @@ struct Config {
     pub exec: String,
     pub no_headers: bool,
     pub delimiter: String,
+    pub out_delimiter: Option<String>,
     pub quote: String,
     pub arg_regex: String,
     pub new_column_name: String,
@@ -46,9 +47,9 @@ fn main() -> Result<()> {
                 .takes_value(true),
         )
         .arg(
-            Arg::with_name("no-header")
+            Arg::with_name("no-headers")
                 .short("n")
-                .long("no-header")
+                .long("no-headers")
                 .help("Do not read the first line as a header line")
                 .takes_value(false),
         )
@@ -61,6 +62,13 @@ fn main() -> Result<()> {
                 .help("CSV delimiter (\\t for tabs)")
                 .takes_value(true),
         )
+        .arg(
+            Arg::with_name("out-delimiter")
+                .long("out-delimiter")
+                .value_name("CHAR")
+                .help("Output CSV delimiter, if different from delimiter (\\t for tabs)")
+                .takes_value(true),
+        )
         .arg(
             Arg::with_name("quote")
                 .long("quote")
@@ -74,7 +82,15 @@ fn main() -> Result<()> {
                 .long("arg-regex")
                 .value_name("REGEX")
                 .default_value(r"\$([0-9]+)")
-                .help("Regex used to parse the column position in the command args. Syntax: https://docs.rs/regex/1.3.4/regex/index.html#syntax")
+                .help(
+                    "
+Regex used to parse the column position in the command args.
+Position begins at 1.
+Only the first capturing group is used.
+Syntax: https://docs.rs/regex/1.3.4/regex/index.html#syntax
+"
+                    .trim_start(),
+                )
                 .takes_value(true),
         )
         .arg(
@@ -100,6 +116,7 @@ fn main() -> Result<()> {
             .value_of("delimiter")
             .map(String::from)
             .unwrap_or_else(String::new),
+        out_delimiter: matches.value_of("out-delimiter").map(String::from),
         quote: matches
             .value_of("quote")
             .map(String::from)
@@ -146,12 +163,22 @@ fn run(config: Config) -> Result<()> {
         }
     };
 
-    let delimiter: u8 = if &config.delimiter == r"\t" {
-        b'\t'
-    } else {
-        read_one_ascii_char(&config.delimiter)?
+    let read_delimiter = |value: &str| -> Result<u8> {
+        if value == r"\t" {
+            Ok(b'\t')
+        } else {
+            read_one_ascii_char(value)
+        }
     };
 
+    let delimiter: u8 = read_delimiter(&config.delimiter)?;
+
+    let out_delimiter: u8 = config
+        .out_delimiter
+        .map(|d| read_delimiter(&d))
+        .transpose()?
+        .unwrap_or(delimiter);
+
     let quote: u8 = read_one_ascii_char(&config.quote)?;
 
     let variable_regex = Regex::new(&config.arg_regex)?;
@@ -165,7 +192,7 @@ fn run(config: Config) -> Result<()> {
         .from_reader(reader);
 
     let mut csv_writer = csv::WriterBuilder::new()
-        .delimiter(delimiter)
+        .delimiter(out_delimiter)
         .quote(quote)
         .from_writer(writer);
 
@@ -192,6 +219,8 @@ fn run(config: Config) -> Result<()> {
                         let record_value = caps
                             .get(1)
                             .and_then(|position| position.as_str().parse::<usize>().ok())
+                            // Column position begins at 1
+                            .and_then(|position| position.checked_sub(1))
                             .and_then(|position| record.get(position));
                         match record_value {
                             None => "",
